package cc.toph.simplycompat.compat;

import cc.toph.simplycompat.registry.ConfigRegistry;
import cc.toph.simplycompat.util.ToolMaterials;
import com.drmangotea.tfmg.registry.TFMGTiers;
import net.minecraft.util.LazyLoadedValue;
import net.minecraft.world.item.Items;
import net.minecraft.world.item.crafting.Ingredient;
import net.minecraft.world.level.ItemLike;
import org.jetbrains.annotations.NotNull;

import java.util.function.Supplier;

public enum TFMGToolMaterials implements ToolMaterials<TFMGToolMaterials> {
    ALUMINUM(
            TFMGTiers.ALUMINUM.getLevel(),
            TFMGTiers.ALUMINUM.getUses(),
            TFMGTiers.ALUMINUM.getSpeed(),
            TFMGTiers.ALUMINUM.getAttackDamageBonus(),
            ConfigRegistry.WEAPON_ATTRIBUTES.ALUMINUM,
            TFMGTiers.ALUMINUM.getEnchantmentValue(),
            ConfigRegistry.WEAPON_ATTRIBUTES.ALUMINUM_ENABLED,
//            () -> Ingredient.of(new ItemLike[]{(ItemLike) TFMGItems.ALUMINUM_INGOT.get()})
            () -> Ingredient.of(new ItemLike[]{(ItemLike) Items.STICK})
    ),
    LEAD(
            TFMGTiers.LEAD.getLevel(),
            TFMGTiers.LEAD.getUses(),
            TFMGTiers.LEAD.getSpeed(),
            TFMGTiers.LEAD.getAttackDamageBonus(),
            ConfigRegistry.WEAPON_ATTRIBUTES.LEAD,
            TFMGTiers.LEAD.getEnchantmentValue(),
            ConfigRegistry.WEAPON_ATTRIBUTES.LEAD_ENABLED,
//            () -> Ingredient.of(new ItemLike[]{(ItemLike) TFMGItems.LEAD_INGOT.get()})
            () -> Ingredient.of(new ItemLike[]{(ItemLike) Items.STICK})
    ),
    STEEL(
            TFMGTiers.STEEL.getLevel(),
            TFMGTiers.STEEL.getUses(),
            TFMGTiers.STEEL.getSpeed(),
            TFMGTiers.STEEL.getAttackDamageBonus(),
            ConfigRegistry.WEAPON_ATTRIBUTES.STEEL,
            TFMGTiers.STEEL.getEnchantmentValue(),
            ConfigRegistry.WEAPON_ATTRIBUTES.STEEL_ENABLED,
//            () -> Ingredient.of(new ItemLike[]{(ItemLike) TFMGItems.STEEL_INGOT.get()})
            () -> Ingredient.of(new ItemLike[]{(ItemLike) Items.STICK})
    );

    private final int level;
    private final int uses;
    private final float speed;
    private final float attackDamageBonus;
    private final float damageModifier;
    private final int enchantmentValue;
    private final boolean enabled;
    private final LazyLoadedValue<Ingredient> repairIngredient;

    TFMGToolMaterials(
            int level,
            int uses,
            float speed,
            float attackDamageBonus,
            float damageModifier,
            int enchantmentValue,
            boolean enabled,
            Supplier<Ingredient> repairIngredient
    ) {
        this.level = level;
        this.uses = uses;
        this.speed = speed;
        this.attackDamageBonus = attackDamageBonus;
        this.enchantmentValue = enchantmentValue;
        this.damageModifier = damageModifier;
        this.enabled = enabled;
        this.repairIngredient = new LazyLoadedValue(repairIngredient);


    }

    @Override
    public String getName() {
        return this.name().toLowerCase();
    }

    @Override
    public int getUses() {
        return uses;
    }

    @Override
    public float getSpeed() {
        return speed;
    }

    @Override
    public float getAttackDamageBonus() {
        return attackDamageBonus;
    }

    @Override
    public float getDamageModifier() {
        return damageModifier;
    }

    @Override
    public int getLevel() {
        return level;
    }

    @Override
    public int getEnchantmentValue() {
        return enchantmentValue;
    }

    @Override
    public boolean isEnabled() {
        return enabled;
    }

    @Override
    public @NotNull Ingredient getRepairIngredient() {
        return this.repairIngredient.get();
    }


    @Override
    public TFMGToolMaterials[] getValues() {
        return values();
    }

}