package cc.toph.simplycompat.registry;

import cc.toph.simplycompat.compat.CompatRecord;
import cc.toph.simplycompat.compat.CreateToolMaterials;
import cc.toph.simplycompat.compat.TFMGToolMaterials;
import com.drmangotea.tfmg.CreateTFMG;
import com.simibubi.create.Create;


/**
 * A registry for compatibility records. Each record represents
 * a supported mod's integration setup.
 *
 * <p>Use {@link #registerAll()} to initialize all integrations.</p>
 */

public final class CompatRegistry {

    /**
     * Compatibility setup for the Create mod.
     */
    public static final CompatRecord<CreateToolMaterials> CREATE = new CompatRecord<>(
            Create.ID,
            "0.5.1.j-55",
            CreateToolMaterials.class
    );

    /**
     * Compatibility setup for the TFMG mod.
     */
    public static final CompatRecord<TFMGToolMaterials> TFMG = new CompatRecord<>(
            CreateTFMG.MOD_ID,
            "0.9.3-1.20.1",
            TFMGToolMaterials.class
    );

    /**
     * Initializes all declared compat records.
     */
    public static void registerAll() {
        CompatRegistry.CREATE.register();
        CompatRegistry.TFMG.register();
    }
}

